==> jc-1.4.0.tar.gz: java/util/AbstractSequentialList.h <==
// public abstract class java.util.AbstractSequentialList

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 8ea716c64b77f8eb java_util_AbstractCollection
// @dep_class f5238436362828db java_util_AbstractList
// @dep_class 6d7997e879c41059 java_util_AbstractSequentialList

// header file dependencies
// @dep_header java_util_AbstractList

#include "java/util/AbstractList.h"

#ifndef _JC_java_util_AbstractSequentialList_H_
#define _JC_java_util_AbstractSequentialList_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_Collection$object;
struct _jc_java_util_Iterator$object;
struct _jc_java_util_ListIterator$object;

// Typedefs
typedef struct _jc_java_util_AbstractSequentialList$sub_refs	_jc_java_util_AbstractSequentialList$sub_refs;
typedef struct _jc_java_util_AbstractSequentialList$sub_nonrefs	_jc_java_util_AbstractSequentialList$sub_nonrefs;
typedef struct _jc_java_util_AbstractSequentialList$refs	_jc_java_util_AbstractSequentialList$refs;
typedef struct _jc_java_util_AbstractSequentialList$nonrefs	_jc_java_util_AbstractSequentialList$nonrefs;
typedef struct _jc_java_util_AbstractSequentialList$object	_jc_java_util_AbstractSequentialList$object;

typedef const struct _jc_java_util_AbstractSequentialList$vmethods	_jc_java_util_AbstractSequentialList$vmethods;
typedef const struct _jc_java_util_AbstractSequentialList$vtable	_jc_java_util_AbstractSequentialList$vtable;
typedef const struct _jc_java_util_AbstractSequentialList$vtype	_jc_java_util_AbstractSequentialList$vtype;

// Constructors
extern void _jc_java_util_AbstractSequentialList$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_util_AbstractSequentialList$object *);

// Virtual methods
extern void _jc_java_util_AbstractSequentialList$method$add$9953f092f36e3303(_jc_env *, struct _jc_java_util_AbstractSequentialList$object *, jint, struct _jc_java_lang_Object$object *);
extern jboolean _jc_java_util_AbstractSequentialList$method$addAll$28b94b9c09be8eeb(_jc_env *, struct _jc_java_util_AbstractSequentialList$object *, jint, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_java_util_AbstractSequentialList$method$get$a706240e1333824b(_jc_env *, struct _jc_java_util_AbstractSequentialList$object *, jint);
extern struct _jc_object *_jc_java_util_AbstractSequentialList$method$iterator$3cc91493d50f531c(_jc_env *, struct _jc_java_util_AbstractSequentialList$object *);
extern struct _jc_object *_jc_java_util_AbstractSequentialList$method$listIterator$5712c48727d9c4a4(_jc_env *, struct _jc_java_util_AbstractSequentialList$object *, jint);
extern struct _jc_java_lang_Object$object *_jc_java_util_AbstractSequentialList$method$remove$ce2b087495782dc2(_jc_env *, struct _jc_java_util_AbstractSequentialList$object *, jint);
extern struct _jc_java_lang_Object$object *_jc_java_util_AbstractSequentialList$method$set$21145a3aa89a3e6d(_jc_env *, struct _jc_java_util_AbstractSequentialList$object *, jint, struct _jc_java_lang_Object$object *);

// Virtual method descriptors
extern _jc_method _jc_java_util_AbstractSequentialList$method_info$add$9953f092f36e3303;
extern _jc_method _jc_java_util_AbstractSequentialList$method_info$addAll$28b94b9c09be8eeb;
extern _jc_method _jc_java_util_AbstractSequentialList$method_info$get$a706240e1333824b;
extern _jc_method _jc_java_util_AbstractSequentialList$method_info$iterator$3cc91493d50f531c;
extern _jc_method _jc_java_util_AbstractSequentialList$method_info$listIterator$5712c48727d9c4a4;
extern _jc_method _jc_java_util_AbstractSequentialList$method_info$remove$ce2b087495782dc2;
extern _jc_method _jc_java_util_AbstractSequentialList$method_info$set$21145a3aa89a3e6d;

// Virtual methods structure
struct _jc_java_util_AbstractSequentialList$vmethods {
	void	(*add$9953f092f36e3303)(_jc_env *, struct _jc_java_util_AbstractSequentialList$object *, jint, struct _jc_java_lang_Object$object *);
	jboolean	(*addAll$28b94b9c09be8eeb)(_jc_env *, struct _jc_java_util_AbstractSequentialList$object *, jint, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*get$a706240e1333824b)(_jc_env *, struct _jc_java_util_AbstractSequentialList$object *, jint);
	struct _jc_object	*(*iterator$3cc91493d50f531c)(_jc_env *, struct _jc_java_util_AbstractSequentialList$object *);
	struct _jc_object	*(*listIterator$5712c48727d9c4a4)(_jc_env *, struct _jc_java_util_AbstractSequentialList$object *, jint);
	struct _jc_java_lang_Object$object	*(*remove$ce2b087495782dc2)(_jc_env *, struct _jc_java_util_AbstractSequentialList$object *, jint);
	struct _jc_java_lang_Object$object	*(*set$21145a3aa89a3e6d)(_jc_env *, struct _jc_java_util_AbstractSequentialList$object *, jint, struct _jc_java_lang_Object$object *);
};

// Vtable
struct _jc_java_util_AbstractSequentialList$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_AbstractCollection$vmethods	java_util_AbstractCollection;
	_jc_java_util_AbstractList$vmethods	java_util_AbstractList;
	_jc_java_util_AbstractSequentialList$vmethods	java_util_AbstractSequentialList;
};

// Vtype
struct _jc_java_util_AbstractSequentialList$vtype {
	_jc_type			type;
	_jc_java_util_AbstractSequentialList$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_AbstractSequentialList$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_util_AbstractSequentialList$refs {
    _jc_java_util_AbstractSequentialList$sub_refs	java_util_AbstractSequentialList;
    _jc_java_util_AbstractList$sub_refs	java_util_AbstractList;
    _jc_java_util_AbstractCollection$sub_refs	java_util_AbstractCollection;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_AbstractSequentialList$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_AbstractSequentialList$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_AbstractCollection$sub_nonrefs	java_util_AbstractCollection;
    _jc_java_util_AbstractList$sub_nonrefs	java_util_AbstractList;
    _jc_java_util_AbstractSequentialList$sub_nonrefs	java_util_AbstractSequentialList;
};

// Object instance structure
struct _jc_java_util_AbstractSequentialList$object {
	_jc_java_util_AbstractSequentialList$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_AbstractSequentialList$vtype	*vtype;
	_jc_java_util_AbstractSequentialList$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_AbstractSequentialList$vtype _jc_java_util_AbstractSequentialList$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_AbstractSequentialList, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_AbstractSequentialList$class_object;

#endif	/* _JC_java_util_AbstractSequentialList_H_ */

==> jc-1.4.6.tar.gz: java/util/AbstractSequentialList.h <==
// public abstract class java.util.AbstractSequentialList

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 8ea716c64b77f8eb java_util_AbstractCollection
// @dep_class f5238436362828db java_util_AbstractList
// @dep_class 6d7997e879c41059 java_util_AbstractSequentialList

// header file dependencies
// @dep_header java_util_AbstractList

#include "java/util/AbstractList.h"

#ifndef _JC_java_util_AbstractSequentialList_H_
#define _JC_java_util_AbstractSequentialList_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_Collection$object;
struct _jc_java_util_Iterator$object;
struct _jc_java_util_ListIterator$object;

// Typedefs
typedef struct _jc_java_util_AbstractSequentialList$sub_refs	_jc_java_util_AbstractSequentialList$sub_refs;
typedef struct _jc_java_util_AbstractSequentialList$sub_nonrefs	_jc_java_util_AbstractSequentialList$sub_nonrefs;
typedef struct _jc_java_util_AbstractSequentialList$refs	_jc_java_util_AbstractSequentialList$refs;
typedef struct _jc_java_util_AbstractSequentialList$nonrefs	_jc_java_util_AbstractSequentialList$nonrefs;
typedef struct _jc_java_util_AbstractSequentialList$object	_jc_java_util_AbstractSequentialList$object;

typedef const struct _jc_java_util_AbstractSequentialList$vmethods	_jc_java_util_AbstractSequentialList$vmethods;
typedef const struct _jc_java_util_AbstractSequentialList$vtable	_jc_java_util_AbstractSequentialList$vtable;
typedef const struct _jc_java_util_AbstractSequentialList$vtype	_jc_java_util_AbstractSequentialList$vtype;

// Constructors
extern void _jc_java_util_AbstractSequentialList$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_util_AbstractSequentialList$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_java_util_AbstractSequentialList$method$add$9953f092f36e3303(_jc_env *, struct _jc_java_util_AbstractSequentialList$object *, jint, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern jboolean _jc_java_util_AbstractSequentialList$method$addAll$28b94b9c09be8eeb(_jc_env *, struct _jc_java_util_AbstractSequentialList$object *, jint, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_java_util_AbstractSequentialList$method$get$a706240e1333824b(_jc_env *, struct _jc_java_util_AbstractSequentialList$object *, jint) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_java_util_AbstractSequentialList$method$iterator$3cc91493d50f531c(_jc_env *, struct _jc_java_util_AbstractSequentialList$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_java_util_AbstractSequentialList$method$listIterator$5712c48727d9c4a4(_jc_env *, struct _jc_java_util_AbstractSequentialList$object *, jint) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_java_util_AbstractSequentialList$method$remove$ce2b087495782dc2(_jc_env *, struct _jc_java_util_AbstractSequentialList$object *, jint) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_java_util_AbstractSequentialList$method$set$21145a3aa89a3e6d(_jc_env *, struct _jc_java_util_AbstractSequentialList$object *, jint, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_util_AbstractSequentialList$method_info$add$9953f092f36e3303;
extern _jc_method _jc_java_util_AbstractSequentialList$method_info$addAll$28b94b9c09be8eeb;
extern _jc_method _jc_java_util_AbstractSequentialList$method_info$get$a706240e1333824b;
extern _jc_method _jc_java_util_AbstractSequentialList$method_info$iterator$3cc91493d50f531c;
extern _jc_method _jc_java_util_AbstractSequentialList$method_info$listIterator$5712c48727d9c4a4;
extern _jc_method _jc_java_util_AbstractSequentialList$method_info$remove$ce2b087495782dc2;
extern _jc_method _jc_java_util_AbstractSequentialList$method_info$set$21145a3aa89a3e6d;

// Virtual methods structure
struct _jc_java_util_AbstractSequentialList$vmethods {
	void	(*add$9953f092f36e3303)(_jc_env *, struct _jc_java_util_AbstractSequentialList$object *, jint, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	jboolean	(*addAll$28b94b9c09be8eeb)(_jc_env *, struct _jc_java_util_AbstractSequentialList$object *, jint, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*get$a706240e1333824b)(_jc_env *, struct _jc_java_util_AbstractSequentialList$object *, jint) _JC_JCNI_ATTR;
	struct _jc_object	*(*iterator$3cc91493d50f531c)(_jc_env *, struct _jc_java_util_AbstractSequentialList$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*listIterator$5712c48727d9c4a4)(_jc_env *, struct _jc_java_util_AbstractSequentialList$object *, jint) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*remove$ce2b087495782dc2)(_jc_env *, struct _jc_java_util_AbstractSequentialList$object *, jint) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*set$21145a3aa89a3e6d)(_jc_env *, struct _jc_java_util_AbstractSequentialList$object *, jint, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_util_AbstractSequentialList$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_AbstractCollection$vmethods	java_util_AbstractCollection;
	_jc_java_util_AbstractList$vmethods	java_util_AbstractList;
	_jc_java_util_AbstractSequentialList$vmethods	java_util_AbstractSequentialList;
};

// Vtype
struct _jc_java_util_AbstractSequentialList$vtype {
	_jc_type			type;
	_jc_java_util_AbstractSequentialList$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_AbstractSequentialList$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_util_AbstractSequentialList$refs {
    _jc_java_util_AbstractSequentialList$sub_refs	java_util_AbstractSequentialList;
    _jc_java_util_AbstractList$sub_refs	java_util_AbstractList;
    _jc_java_util_AbstractCollection$sub_refs	java_util_AbstractCollection;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_AbstractSequentialList$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_AbstractSequentialList$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_AbstractCollection$sub_nonrefs	java_util_AbstractCollection;
    _jc_java_util_AbstractList$sub_nonrefs	java_util_AbstractList;
    _jc_java_util_AbstractSequentialList$sub_nonrefs	java_util_AbstractSequentialList;
};

// Object instance structure
struct _jc_java_util_AbstractSequentialList$object {
	_jc_java_util_AbstractSequentialList$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_AbstractSequentialList$vtype	*vtype;
	_jc_java_util_AbstractSequentialList$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_AbstractSequentialList$vtype _jc_java_util_AbstractSequentialList$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_AbstractSequentialList, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_AbstractSequentialList$class_object;

#endif	/* _JC_java_util_AbstractSequentialList_H_ */
